summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorFabien Freling <fabien.freling@nokia.com>2011-05-03 14:28:56 +0200
committerFabien Freling <fabien.freling@nokia.com>2011-05-10 11:45:33 +0200
commitdaf37954617330e5840678292aaa82ceab6259df (patch)
tree37b90d6187661a2232b7f0619dd2087c4aaacdf0
parent1dab1ce6af149a1a9b3cc1be7aeb7a09bfd56b19 (diff)
Change the repaint() call to an update().
In show_sys(), if we directly call repaint() this will triggers too many UpdateRequest events. This fixes the qwidget autotest "compatibilityChildInsertedEvents". Reviewed-by: Richard Moe Gustavsen (cherry picked from commit 747962e6ec20a59b7e2ed67c5cd685258f199a86)
-rw-r--r--src/gui/kernel/qwidget_mac.mm4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gui/kernel/qwidget_mac.mm b/src/gui/kernel/qwidget_mac.mm
index 8dc9d2e545..27a1bb6940 100644
--- a/src/gui/kernel/qwidget_mac.mm
+++ b/src/gui/kernel/qwidget_mac.mm
@@ -3526,8 +3526,8 @@ void QWidgetPrivate::show_sys()
// INVARIANT: q is native. Just show the view:
[view setHidden:NO];
} else {
- // INVARIANT: q is alien. Repaint q instead:
- q->repaint();
+ // INVARIANT: q is alien. Update q instead:
+ q->update();
}
#endif
}